@@ -66,6 +66,10 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
         if self.data.get('confirmacion'):
             dom.setAttribute('Confirmacion', self.data.get('confirmacion'))  # opcional
 
+        # <cfdi:InformacionGlobal Periodicidad="01" Meses="01" Año="2021"/>
+        if self.data.get('factura_global') == 'SI':
+            dom.appendChild(self.get_informacion_global())
+
         dom.appendChild(self.get_emisor())
         dom.appendChild(self.get_receptor())
 
@@ -138,6 +142,16 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
         except Exception as e:
             raise Exception("Ocurrio un error al agregar los cfdis relacionados. Error::: " + str(e))
 
+    def get_informacion_global(self):
+        try:
+            informacion_global = self.dom.createElement('cfdi:InformacionGlobal')
+            informacion_global.setAttribute('Periodicidad', self.data.get('periodicidad'))
+            informacion_global.setAttribute('Meses', self.data.get('meses'))
+            informacion_global.setAttribute('Año', self.data.get('año'))
+            return informacion_global
+        except Exception as e:
+            raise Exception("Ocurrio un error al agregar al emisor. Error::: " + str(e))
+
     def get_emisor(self):
         try:
             emisor = self.dom.createElement('cfdi:Emisor')
@@ -580,7 +594,8 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
                 cartaporte_mercancia.setAttribute('ValorMercancia', mercancia_data.get('ValorMercancia'))
                 cartaporte_mercancia.setAttribute('Moneda', mercancia_data.get('Moneda'))
 
-                cartaporte_mercancia.setAttribute('MaterialPeligroso', mercancia_data.get('MaterialPeligroso', ''))
+                if mercancia_data.get('MaterialPeligroso') == 'No':
+                    cartaporte_mercancia.setAttribute('MaterialPeligroso', mercancia_data.get('MaterialPeligroso', ''))
 
                 if mercancia_data.get('MaterialPeligroso') == 'Sí':
                     cartaporte_mercancia.setAttribute('MaterialPeligroso', mercancia_data.get('MaterialPeligroso'))
